/****************************************************************************
** Meta object code from reading C++ file 'ksmserverinterfaceadaptor.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "ksmserverinterfaceadaptor.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'ksmserverinterfaceadaptor.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN25KSMServerInterfaceAdaptorE_t {};
} // unnamed namespace

template <> constexpr inline auto KSMServerInterfaceAdaptor::qt_create_metaobjectdata<qt_meta_tag_ZN25KSMServerInterfaceAdaptorE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KSMServerInterfaceAdaptor",
        "D-Bus Interface",
        "org.kde.KSMServerInterface",
        "D-Bus Introspection",
        "  <interface name=\"org.kde.KSMServerInterface\">\n    <method nam"
        "e=\"isShuttingDown\">\n      <arg direction=\"out\" type=\"b\"/>\n"
        "    </method>\n    <method name=\"sessionList\">\n      <arg direc"
        "tion=\"out\" type=\"as\"/>\n    </method>\n    <method name=\"curr"
        "entSession\">\n      <arg direction=\"out\" type=\"s\"/>\n    </me"
        "thod>\n    <method name=\"saveCurrentSession\"/>\n    <method name"
        "=\"saveCurrentSessionAs\">\n      <arg direction=\"in\" type=\"s\""
        "/>\n    </method>\n    <method name=\"restoreSession\"/>\n    <met"
        "hod name=\"closeSession\">\n      <arg direction=\"out\" type=\"b\""
        "/>\n    </method>\n    <method name=\"resetLogout\"/>\n  </interfa"
        "ce>\n",
        "closeSession",
        "",
        "currentSession",
        "isShuttingDown",
        "resetLogout",
        "restoreSession",
        "saveCurrentSession",
        "saveCurrentSessionAs",
        "in0",
        "sessionList"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'closeSession'
        QtMocHelpers::SlotData<bool()>(5, 6, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'currentSession'
        QtMocHelpers::SlotData<QString()>(7, 6, QMC::AccessPublic, QMetaType::QString),
        // Slot 'isShuttingDown'
        QtMocHelpers::SlotData<bool()>(8, 6, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'resetLogout'
        QtMocHelpers::SlotData<void()>(9, 6, QMC::AccessPublic, QMetaType::Void),
        // Slot 'restoreSession'
        QtMocHelpers::SlotData<void()>(10, 6, QMC::AccessPublic, QMetaType::Void),
        // Slot 'saveCurrentSession'
        QtMocHelpers::SlotData<void()>(11, 6, QMC::AccessPublic, QMetaType::Void),
        // Slot 'saveCurrentSessionAs'
        QtMocHelpers::SlotData<void(const QString &)>(12, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 13 },
        }}),
        // Slot 'sessionList'
        QtMocHelpers::SlotData<QStringList()>(14, 6, QMC::AccessPublic, QMetaType::QStringList),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
    });
    return QtMocHelpers::metaObjectData<KSMServerInterfaceAdaptor, qt_meta_tag_ZN25KSMServerInterfaceAdaptorE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject KSMServerInterfaceAdaptor::staticMetaObject = { {
    QMetaObject::SuperData::link<QDBusAbstractAdaptor::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN25KSMServerInterfaceAdaptorE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN25KSMServerInterfaceAdaptorE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN25KSMServerInterfaceAdaptorE_t>.metaTypes,
    nullptr
} };

void KSMServerInterfaceAdaptor::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<KSMServerInterfaceAdaptor *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: { bool _r = _t->closeSession();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 1: { QString _r = _t->currentSession();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 2: { bool _r = _t->isShuttingDown();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 3: _t->resetLogout(); break;
        case 4: _t->restoreSession(); break;
        case 5: _t->saveCurrentSession(); break;
        case 6: _t->saveCurrentSessionAs((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 7: { QStringList _r = _t->sessionList();
            if (_a[0]) *reinterpret_cast<QStringList*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
}

const QMetaObject *KSMServerInterfaceAdaptor::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KSMServerInterfaceAdaptor::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN25KSMServerInterfaceAdaptorE_t>.strings))
        return static_cast<void*>(this);
    return QDBusAbstractAdaptor::qt_metacast(_clname);
}

int KSMServerInterfaceAdaptor::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDBusAbstractAdaptor::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 8)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 8;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 8)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 8;
    }
    return _id;
}
QT_WARNING_POP
